Mopidy-InternetArchive
========================================================================

Mopidy-InternetArchive is a Mopidy_ extension for playing music from
the `Internet Archive`_.

This extension lets you search for and stream recordings ranging from
`alternative news programming`_, to `Grateful Dead concerts`_, to `Old
Time Radio shows`_, to `book and poetry readings`_, to `original
music`_ uploaded by Internet Archive users.  It also gives you access
to a vast number of high-quality live recordings from the `Live Music
Archive`_, and thousands of free audiobooks from the LibriVox_
collection.


.. toctree::
   :maxdepth: 2

   intro
   install
   config
   changelog
   license


.. _Mopidy: http://www.mopidy.com/
.. _Internet Archive: http://archive.org
.. _alternative news programming: https://archive.org/details/audio_news
.. _Grateful Dead concerts: https://archive.org/details/GratefulDead
.. _Old Time Radio shows: https://archive.org/details/radioprograms
.. _book and poetry readings: https://archive.org/details/audio_bookspoetry
.. _original music: https://archive.org/details/opensource_audio
.. _Live Music Archive: https://archive.org/details/etree
.. _LibriVox: https://archive.org/details/librivoxaudio
.. _donate: https://archive.org/donate/
